@@ -16,6 +16,7 @@
 #include <stdbool.h>
 #include <unistd.h>
 #include <string.h>
+#include <limits.h>
 #include <fcntl.h>
 #include <time.h>
 #include <signal.h>
@@ -418,7 +419,7 @@ int fetch_request(t_session *session) {
 							*strend = '\0';
 							content_length = str2int(strstart);
 							*strend = '\r';
-							if (content_length < 0) {
+							if ((content_length < 0) || (INT_MAX - content_length - 2 <= header_length)) {
 								result = 400;
 								break;
 							}
