@@ -17,8 +17,10 @@
 #include <string.h>
 #include <pthread.h>
 #include <pwd.h>
+#include <sys/socket.h>
 #include "alternative.h"
 #include "libstr.h"
+#include "libip.h"
 #include "liblist.h"
 #include "session.h"
 #include "log.h"
@@ -29,7 +31,7 @@
 #include "command.h"
 #endif
 
-int new_client_id = 0;
+static int new_client_id = 0;
 
 /* Set the entries in a session-record to the default values.
  */
@@ -99,6 +101,7 @@ void init_session(t_session *session) {
 	if ((session->client_id = new_client_id++) == MAX_CHILD_ID) {
 		new_client_id = 0;
 	}
+	session->request_limit = true;
 	session->force_quit = false;
 	session->kept_alive = 0;
 #ifdef HAVE_SSL
@@ -231,7 +234,7 @@ int get_target_extension(t_session *session) {
 	if ((session->extension = strrchr(last_slash, '.')) != NULL) {
 		session->extension++;
 	} else {
-		session->extension = session->config->no_extension_as;
+		session->extension = session->host->no_extension_as;
 	}
 
 #ifdef CIFS
@@ -434,6 +437,50 @@ bool client_is_rejected_bot(t_session *session) {
 	return false;
 }
 
+/* Remove port from hostname
+ */
+int remove_port_from_hostname(char *hostname, t_binding *binding) {
+	char *c, old;
+#ifdef HAVE_IPV6
+	char ip[IPv6_LEN];
+#endif
+
+	if (hostname == NULL) {
+		return -1;
+	}
+
+	if (binding->interface.family == AF_INET) {
+		if ((c = strrchr(hostname, ':')) != NULL) {
+			if (c == hostname) {
+				return -1;
+			}
+
+			*c = '\0';
+		}
+#ifdef HAVE_IPV6
+	} else if (binding->interface.family == AF_INET6) {
+		if ((c = strrchr(hostname, '.')) != NULL) {
+			if (c == hostname) {
+				return -1;
+			}
+
+			old = *c;
+			*c = '\0';
+
+			if ((*hostname == '[') && (*(c - 1) == ']')) {
+				return 0;
+			}
+
+			if (inet_pton(AF_INET6, hostname, ip) <= 0) {
+				*c = old;
+			}
+		}
+#endif
+	}
+
+	return 0;
+}
+
 /* Prevent cross-site scripting.
  */
 int prevent_xss(t_session *session) {
