@@ -469,8 +469,8 @@ int execute_cgi(t_session *session) {
 #endif
 
 	if (session->cgi_type != fastcgi) {
-		wrap_cgi = (session->config->cgi_wrapper != NULL) && ((session->host->wrap_cgi != NULL) ||
-		           ((session->local_user != NULL) && session->config->wrap_user_cgi));
+		wrap_cgi = (session->host->wrap_cgi != NULL) ||
+			((session->local_user != NULL) && session->config->wrap_user_cgi);
 	} else {
 		wrap_cgi = false;
 	}
