@@ -70,283 +70,277 @@ bool toolkit_setting(char *key, char *value, t_url_toolkit *toolkit) {
 	}
 
 	if (strcmp(key, "toolkitid") == 0) {
-		if ((toolkit->toolkit_id = strdup(value)) == NULL) {
-			return false;
-		}
+		return (toolkit->toolkit_id = strdup(value)) != NULL;
+	}
+
+	if ((new_rule = (t_toolkit_rule*)malloc(sizeof(t_toolkit_rule))) == NULL) {
+		return false;
+	} else if (toolkit->toolkit_rule == NULL) {
+		toolkit->toolkit_rule = new_rule;
 	} else {
-		if ((new_rule = (t_toolkit_rule*)malloc(sizeof(t_toolkit_rule))) == NULL) {
-			return false;
-		} else if (toolkit->toolkit_rule == NULL) {
-			toolkit->toolkit_rule = new_rule;
-		} else {
-			rule = toolkit->toolkit_rule;
-			while (rule->next != NULL) {
-				rule = rule->next;
-			}
-			rule->next = new_rule;
+		rule = toolkit->toolkit_rule;
+		while (rule->next != NULL) {
+			rule = rule->next;
 		}
+		rule->next = new_rule;
+	}
 
-		new_rule->condition = tc_none;
-		new_rule->operation = to_none;
-		new_rule->flow = tf_continue;
-		new_rule->conditional_flow = tf_continue;
-		new_rule->match_loop = 1;
-		new_rule->parameter = NULL;
-		new_rule->value = 0;
-		new_rule->next = NULL;
+	new_rule->condition = tc_none;
+	new_rule->operation = to_none;
+	new_rule->flow = tf_continue;
+	new_rule->conditional_flow = tf_continue;
+	new_rule->match_loop = 1;
+	new_rule->parameter = NULL;
+	new_rule->value = 0;
+	new_rule->next = NULL;
 
-		if (strcmp(key, "match") == 0) {
-			/* Match
+	if (strcmp(key, "match") == 0) {
+		/* Match
+		 */
+		new_rule->condition = tc_match;
+		if (split_string(value, &value, &rest, ' ') == -1) {
+			return false;
+		} else if (regcomp(&(new_rule->pattern), value, REG_EXTENDED) != 0) {
+			return false;
+		}
+		split_string(rest, &value, &rest, ' ');
+		
+		if (strcasecmp(value, "ban") == 0) {
+			/* Match Ban
 			 */
-			new_rule->condition = tc_match;
-			if (split_string(value, &value, &rest, ' ') == -1) {
-				return false;
-			} else if (regcomp(&(new_rule->pattern), value, REG_EXTENDED) != 0) {
+			new_rule->operation = to_ban;
+			if ((new_rule->value = str2int(rest)) == false) {
 				return false;
 			}
-			split_string(rest, &value, &rest, ' ');
-			
-			if (strcasecmp(value, "ban") == 0) {
-				/* Match Ban
-				 */
-				new_rule->operation = to_ban;
-				if ((new_rule->value = str2int(rest)) == false) {
-					return false;
-				}
-			} else if (strcasecmp(value, "call") == 0) {
-				/* Match Call
-				 */
-				new_rule->operation = to_sub;
-				if (rest == NULL) {
-					return false;
-				} else if ((new_rule->parameter = strdup(rest)) == NULL) {
-					return false;
-				}
-			} else if (strcasecmp(value, "denyaccess") == 0) {
-				/* Match DenyAccess
-				 */
-				new_rule->operation = to_denyaccess;
-				new_rule->flow = tf_exit;
-			} else if (strcasecmp(value, "exit") == 0) {
-				/* Match Exit
-				 */
-				new_rule->flow = tf_exit;
-			} else if (strcasecmp(value, "expire") == 0) {
-				/* Match Expire
-				 */
-				new_rule->operation = to_expire;
-				if (split_string(rest, &value, &rest, ' ') == -1) {
-					return false;
-				}
-				if ((new_rule->value = str2int(value)) == -1) {
-					return false;
-				}
-
-				time = new_rule->value;
-
-				split_string(rest, &value, &rest, ' ');
-				if (strcasecmp(value, "minutes") == 0) {
-					new_rule->value *= MINUTE;
-				} else if (strcasecmp(value, "hours") == 0) {
-					new_rule->value *= HOUR;
-				} else if (strcasecmp(value, "days") == 0) {
-					new_rule->value *= DAY;
-				} else if (strcasecmp(value, "weeks") == 0) {
-					new_rule->value *= 7 * DAY;
-				} else if (strcasecmp(value, "months") == 0) {
-					new_rule->value *= 30.5 * DAY;
-				} else if (strcasecmp(value, "seconds") != 0) {
-					return false;
-				}
-
-				if (new_rule->value < time) {
-					return false;
-				}
-
-				if (rest != NULL) {
-					if (strcasecmp(rest, "exit") == 0) {
-						new_rule->flow = tf_exit;
-					} else if (strcasecmp(rest, "return") == 0) {
-						new_rule->flow = tf_return;
-					} else {
-						return false;
-					}
-				}
-			} else if (strcasecmp(value, "goto") == 0) {
-				/* Match Goto
-				 */
-				new_rule->operation = to_sub;
-				new_rule->flow = tf_exit;
-				if (rest == NULL) {
-					return false;
-				} else if ((new_rule->parameter = strdup(rest)) == NULL) {
-					return false;
-				}
-			} else if (strcasecmp(value, "redirect") == 0) {
-				/* Match Redirect
-				 */
-				new_rule->operation = to_redirect;
-				new_rule->flow = tf_exit;
-				if (rest == NULL) {
-					return false;
-				} else if ((new_rule->parameter = strdup(rest)) == NULL) {
-					return false;
-				}
-			} else if (strcasecmp(value, "return") == 0) {
-				/* Match Return
-				 */
-				new_rule->flow = tf_return;
-			} else if (strcasecmp(value, "rewrite") == 0) {
-				/* Match Rewrite
-				 */
-				new_rule->operation = to_rewrite;
-				new_rule->flow = tf_exit;
-
-				split_string(rest, &value, &rest, ' ');
-				if (value == NULL) {
-					return false;
-				} else if ((new_rule->parameter = strdup(value)) == NULL) {
-					return false;
-				}
-
-				if (rest != NULL) {
-					split_string(rest, &value, &rest, ' ');
-					if ((loop = str2int(value)) > 0) {
-						if (loop > MAX_MATCH_LOOP) {
-							return false;
-						}
-						new_rule->match_loop = loop;
-						if ((value = rest) == NULL) {
-							return true;
-						}
-					} else if (rest != NULL) {
-						return false;
-					}
-
-					if (strcasecmp(value, "continue") == 0) {
-						new_rule->flow = tf_continue;
-					} else if (strcasecmp(value, "return") == 0) {
-						new_rule->flow = tf_return;
-					} else {
-						return false;
-					}
-				}
-			} else if (strcasecmp(value, "skip") == 0) {
-				/* Match Skip
-				 */
-				new_rule->operation = to_skip;
-				if ((new_rule->value = str2int(rest)) < 1) {
-					return false;
-				}
-			} else if (strcasecmp(value, "usefastcgi") == 0) {
-				/* Match UseFastCGI
-				 */
-				new_rule->operation = to_fastcgi;
-				new_rule->flow = tf_exit;
-				if (rest == NULL) {
-					return false;
-				} else if ((new_rule->parameter = strdup(rest)) == NULL) {
-					return false;
-				}
-			} else {
-				return false;
-			}
-		} else if (strcmp(key, "call") == 0) {
-			/* Call
+		} else if (strcasecmp(value, "call") == 0) {
+			/* Match Call
 			 */
 			new_rule->operation = to_sub;
+			if (rest == NULL) {
+				return false;
+			} else if ((new_rule->parameter = strdup(rest)) == NULL) {
+				return false;
+			}
+		} else if (strcasecmp(value, "denyaccess") == 0) {
+			/* Match DenyAccess
+			 */
+			new_rule->operation = to_denyaccess;
+			new_rule->flow = tf_exit;
+		} else if (strcasecmp(value, "exit") == 0) {
+			/* Match Exit
+			 */
+			new_rule->flow = tf_exit;
+		} else if (strcasecmp(value, "expire") == 0) {
+			/* Match Expire
+			 */
+			new_rule->operation = to_expire;
+			if (split_string(rest, &value, &rest, ' ') == -1) {
+				return false;
+			}
+			if ((new_rule->value = str2int(value)) == -1) {
+				return false;
+			}
 
+			time = new_rule->value;
+
+			split_string(rest, &value, &rest, ' ');
+			if (strcasecmp(value, "minutes") == 0) {
+				new_rule->value *= MINUTE;
+			} else if (strcasecmp(value, "hours") == 0) {
+				new_rule->value *= HOUR;
+			} else if (strcasecmp(value, "days") == 0) {
+				new_rule->value *= DAY;
+			} else if (strcasecmp(value, "weeks") == 0) {
+				new_rule->value *= 7 * DAY;
+			} else if (strcasecmp(value, "months") == 0) {
+				new_rule->value *= 30.5 * DAY;
+			} else if (strcasecmp(value, "seconds") != 0) {
+				return false;
+			}
+
+			if (new_rule->value < time) {
+				return false;
+			}
+
+			if (rest != NULL) {
+				if (strcasecmp(rest, "exit") == 0) {
+					new_rule->flow = tf_exit;
+				} else if (strcasecmp(rest, "return") == 0) {
+					new_rule->flow = tf_return;
+				} else {
+					return false;
+				}
+			}
+		} else if (strcasecmp(value, "goto") == 0) {
+			/* Match Goto
+			 */
+			new_rule->operation = to_sub;
+			new_rule->flow = tf_exit;
+			if (rest == NULL) {
+				return false;
+			} else if ((new_rule->parameter = strdup(rest)) == NULL) {
+				return false;
+			}
+		} else if (strcasecmp(value, "redirect") == 0) {
+			/* Match Redirect
+			 */
+			new_rule->operation = to_redirect;
+			new_rule->flow = tf_exit;
+			if (rest == NULL) {
+				return false;
+			} else if ((new_rule->parameter = strdup(rest)) == NULL) {
+				return false;
+			}
+		} else if (strcasecmp(value, "return") == 0) {
+			/* Match Return
+			 */
+			new_rule->flow = tf_return;
+		} else if (strcasecmp(value, "rewrite") == 0) {
+			/* Match Rewrite
+			 */
+			new_rule->operation = to_rewrite;
+			new_rule->flow = tf_exit;
+
+			split_string(rest, &value, &rest, ' ');
 			if (value == NULL) {
 				return false;
 			} else if ((new_rule->parameter = strdup(value)) == NULL) {
 				return false;
 			}
-		} else if (strcmp(key, "skip") == 0) {
-			/* Skip
+
+			if (rest != NULL) {
+				split_string(rest, &value, &rest, ' ');
+				if ((loop = str2int(value)) > 0) {
+					if (loop > MAX_MATCH_LOOP) {
+						return false;
+					}
+					new_rule->match_loop = loop;
+					if ((value = rest) == NULL) {
+						return true;
+					}
+				} else if (rest != NULL) {
+					return false;
+				}
+
+				if (strcasecmp(value, "continue") == 0) {
+					new_rule->flow = tf_continue;
+				} else if (strcasecmp(value, "return") == 0) {
+					new_rule->flow = tf_return;
+				} else {
+					return false;
+				}
+			}
+		} else if (strcasecmp(value, "skip") == 0) {
+			/* Match Skip
 			 */
 			new_rule->operation = to_skip;
-
-			if (value == NULL) {
-				return false;
-			} else if ((new_rule->value = str2int(value)) < 1) {
+			if ((new_rule->value = str2int(rest)) < 1) {
 				return false;
 			}
-		} else if (strcmp(key, "requesturi") == 0) {
-			/* RequestURI
+		} else if (strcasecmp(value, "usefastcgi") == 0) {
+			/* Match UseFastCGI
 			 */
-			new_rule->condition = tc_requesturi;
-
-			if (split_string(value, &value, &rest, ' ') == -1) {
+			new_rule->operation = to_fastcgi;
+			new_rule->flow = tf_exit;
+			if (rest == NULL) {
+				return false;
+			} else if ((new_rule->parameter = strdup(rest)) == NULL) {
 				return false;
 			}
-
-			if (strcasecmp(value, "exists") == 0) {
-				new_rule->value = IU_EXISTS;
-			} else if (strcasecmp(value, "isfile") == 0) {
-				new_rule->value = IU_ISFILE;
-			} else if (strcasecmp(value, "isdir") == 0) {
-				new_rule->value = IU_ISDIR;
-			} else {
-				return false;
-			}
-
-			if (strcasecmp(rest, "return") == 0) {
-				new_rule->conditional_flow = tf_return;
-			} else if (strcasecmp(rest, "exit") == 0) {
-				new_rule->conditional_flow = tf_exit;
-			} else {
-				return false;
-			}
-#ifdef HAVE_SSL
-		} else if (strcmp(key, "usessl") == 0) {
-			/* UseSSL
-			 */
-			new_rule->condition = tc_usessl;
-			split_string(value, &value, &rest, ' ');
-
-			if (strcasecmp(value, "call") == 0) {
-				/* UseSSL Call
-				 */
-				new_rule->operation = to_sub;
-				if (rest == NULL) {
-					return false;
-				} else if ((new_rule->parameter = strdup(rest)) == NULL) {
-					return false;
-				}
-			} else if (strcasecmp(value, "exit") == 0) {
-				/* UseSSL Exit
-				 */
-				new_rule->flow = tf_exit;
-			} else if (strcasecmp(value, "goto") == 0) {
-				/* UseSSL Goto
-				 */
-				new_rule->operation = to_sub;
-				new_rule->flow = tf_exit;
-				if (rest == NULL) {
-					return false;
-				} else if ((new_rule->parameter = strdup(rest)) == NULL) {
-					return false;
-				}
-			} else if (strcasecmp(value, "return") == 0) {
-				/* UseSSL Return
-				 */
-				new_rule->flow = tf_return;
-			} else if (strcasecmp(value, "skip") == 0) {
-				/* UseSSL Skip
-				 */
-				new_rule->operation = to_skip;
-				if ((new_rule->value = str2int(rest)) < 1) {
-					return false;
-				}
-			} else {
-				return false;
-			}
-#endif
 		} else {
-			/* Unknown condition
-			 */
 			return false;
 		}
+	} else if (strcmp(key, "call") == 0) {
+		/* Call
+		 */
+		new_rule->operation = to_sub;
+
+		if ((new_rule->parameter = strdup(value)) == NULL) {
+			return false;
+		}
+	} else if (strcmp(key, "skip") == 0) {
+		/* Skip
+		 */
+		new_rule->operation = to_skip;
+
+		if ((new_rule->value = str2int(value)) < 1) {
+			return false;
+		}
+	} else if (strcmp(key, "requesturi") == 0) {
+		/* RequestURI
+		 */
+		new_rule->condition = tc_requesturi;
+
+		if (split_string(value, &value, &rest, ' ') == -1) {
+			return false;
+		}
+
+		if (strcasecmp(value, "exists") == 0) {
+			new_rule->value = IU_EXISTS;
+		} else if (strcasecmp(value, "isfile") == 0) {
+			new_rule->value = IU_ISFILE;
+		} else if (strcasecmp(value, "isdir") == 0) {
+			new_rule->value = IU_ISDIR;
+		} else {
+			return false;
+		}
+
+		if (strcasecmp(rest, "return") == 0) {
+			new_rule->conditional_flow = tf_return;
+		} else if (strcasecmp(rest, "exit") == 0) {
+			new_rule->conditional_flow = tf_exit;
+		} else {
+			return false;
+		}
+#ifdef HAVE_SSL
+	} else if (strcmp(key, "usessl") == 0) {
+		/* UseSSL
+		 */
+		new_rule->condition = tc_usessl;
+		split_string(value, &value, &rest, ' ');
+
+		if (strcasecmp(value, "call") == 0) {
+			/* UseSSL Call
+			 */
+			new_rule->operation = to_sub;
+			if (rest == NULL) {
+				return false;
+			} else if ((new_rule->parameter = strdup(rest)) == NULL) {
+				return false;
+			}
+		} else if (strcasecmp(value, "exit") == 0) {
+			/* UseSSL Exit
+			 */
+			new_rule->flow = tf_exit;
+		} else if (strcasecmp(value, "goto") == 0) {
+			/* UseSSL Goto
+			 */
+			new_rule->operation = to_sub;
+			new_rule->flow = tf_exit;
+			if (rest == NULL) {
+				return false;
+			} else if ((new_rule->parameter = strdup(rest)) == NULL) {
+				return false;
+			}
+		} else if (strcasecmp(value, "return") == 0) {
+			/* UseSSL Return
+			 */
+			new_rule->flow = tf_return;
+		} else if (strcasecmp(value, "skip") == 0) {
+			/* UseSSL Skip
+			 */
+			new_rule->operation = to_skip;
+			if ((new_rule->value = str2int(rest)) < 1) {
+				return false;
+			}
+		} else {
+			return false;
+		}
+#endif
+	} else {
+		/* Unknown condition
+		 */
+		return false;
 	}
 
 	return true;
