@@ -15,4 +15,4 @@
 void init_xslt_module();
 bool can_transform_with_xslt(t_session *session);
 int transform_xml(t_session *session);
-int show_index_via_xslt(t_session *session, t_filelist *file);
+int show_index(t_session *session);
